==> vue3-components-0.0.7.tgz: package/es/selectTime/src/selectTime.vue_vue_type_script_setup_true_lang.js <==
import { defineComponent as u, resolveComponent as s, openBlock as c, createBlock as f, normalizeClass as h, unref as b, withCtx as C, createVNode as l, mergeProps as n } from "vue";
import { createNamespacs as S } from "../../utils/es/src/create.js";
import { selectTimeProps as v } from "./selectTime2.js";
const P = {
  name: "KSelectTime"
}, A = /* @__PURE__ */ u({
  ...P,
  props: v,
  emits: ["update:startTime", "update:endTime"],
  setup(r, { emit: t }) {
    const d = r, i = S("selectTime"), o = (e) => {
      t("update:startTime", e), d.enTimeDisabled && !e && t("update:endTime", "");
    };
    return (e, a) => {
      const m = s("el-time-select"), p = s("el-space");
      return c(), f(p, {
        class: h(b(i).b())
      }, {
        default: C(() => [
          l(m, n({
            "model-value": e.startTime,
            "max-time": e.endTime,
            placeholder: e.startTimePlaceholder,
            start: e.startTimeStart,
            end: e.startTimeEnd,
            step: e.startTimeStep
          }, e.startTimeAttrs, { "onUpdate:modelValue": o }), null, 16, ["model-value", "max-time", "placeholder", "start", "end", "step"]),
          l(m, n({
            "model-value": e.endTime,
            "min-time": e.startTime,
            placeholder: e.endTimePlaceholder,
            start: e.endTimeStart,
            end: e.endTimeEnd,
            step: e.endTimeStep,
            disabled: e.enTimeDisabled && !e.startTime
          }, e.endTimeAttrs, {
            "onUpdate:modelValue": a[0] || (a[0] = (T) => e.$emit("update:endTime", T))
          }), null, 16, ["model-value", "min-time", "placeholder", "start", "end", "step", "disabled"])
        ]),
        _: 1
      }, 8, ["class"]);
    };
  }
});
export {
  A as default
};

==> vue3-components-0.0.8.tgz: package/es/selectTime/src/selectTime.vue_vue_type_script_setup_true_lang.js <==
import { defineComponent as u, resolveComponent as s, openBlock as c, createBlock as f, normalizeClass as h, unref as b, withCtx as C, createVNode as l, mergeProps as n } from "vue";
import { createNamespacs as S } from "@tomiaa/utils";
import { selectTimeProps as v } from "./selectTime2.js";
const P = {
  name: "KSelectTime"
}, A = /* @__PURE__ */ u({
  ...P,
  props: v,
  emits: ["update:startTime", "update:endTime"],
  setup(r, { emit: t }) {
    const d = r, i = S("selectTime"), o = (e) => {
      t("update:startTime", e), d.enTimeDisabled && !e && t("update:endTime", "");
    };
    return (e, m) => {
      const a = s("el-time-select"), p = s("el-space");
      return c(), f(p, {
        class: h(b(i).b())
      }, {
        default: C(() => [
          l(a, n({
            "model-value": e.startTime,
            "max-time": e.endTime,
            placeholder: e.startTimePlaceholder,
            start: e.startTimeStart,
            end: e.startTimeEnd,
            step: e.startTimeStep
          }, e.startTimeAttrs, { "onUpdate:modelValue": o }), null, 16, ["model-value", "max-time", "placeholder", "start", "end", "step"]),
          l(a, n({
            "model-value": e.endTime,
            "min-time": e.startTime,
            placeholder: e.endTimePlaceholder,
            start: e.endTimeStart,
            end: e.endTimeEnd,
            step: e.endTimeStep,
            disabled: e.enTimeDisabled && !e.startTime
          }, e.endTimeAttrs, {
            "onUpdate:modelValue": m[0] || (m[0] = (T) => e.$emit("update:endTime", T))
          }), null, 16, ["model-value", "min-time", "placeholder", "start", "end", "step", "disabled"])
        ]),
        _: 1
      }, 8, ["class"]);
    };
  }
});
export {
  A as default
};
